function [] = daffv17_convert_from_daffv15( daffv15_input_file_path, daffv17_output_file_path, additional_metadata_v17 )
% Reads a DAFF file with file format version 150 (DAFF version 1.5) and
% exports a DAFF file with file format version 170 (DAFF version 1.7)
%
% daffv15_input_file_path   Input file path to DAFF v1.5 content
% daffv17_output_file_path  Output file path (will be DAFF v1.7 content)
% additional_metadata_v17   Extend metadata of target file (must be a daffv17 metadata)
%  
%
    h = DAFFv15( 'open', daffv15_input_file_path );
    
    props = DAFFv15( 'getProperties', h );
    
    metadata_v17 = [];
    if nargin >= 3
        metadata_v17 = additional_metadata_v17;
    end
    
    metadata_v17 = daffv17_add_metadata( metadata_v17, 'Converter', 'String', 'Converted from DAFF version 1.5' );
    metadata_v17 = daffv17_add_metadata( metadata_v17, 'Date of conversion', 'String', date );
    
    metadata_v15 = DAFFv15( 'getMetadata', h );
   
    metadata_field_names = fieldnames( metadata_v15 );
    if size( metadata_field_names, 1 )
       for i = size( metadata_field_names, 1 )
           key = metadata_field_names{i};
           val = metadata_v15.( key );
           if isnumeric( val )
               val = num2str( val );
           end
           metadata_v17 = daffv17_add_metadata( metadata_v17, key, 'String', val );
       end
    end
   
    
    switch( props.contentType )
    case { 'ms', 'mps', 'ps' }
	daffv17_write( 'filename', daffv17_output_file_path, ...                
                'metadata', metadata_v17, ...
                'datafunc', @dfConvertFromDAFFv15MS, ...
                'userdata', h, ...
                'content', props.contentType, ...
                'quantization', props.quantization, ...
                'channels', props.numChannels, ...
                'alphares', props.alphaResolution, ...
                'alpharange', props.alphaRange, ...
                'betares', props.betaResolution, ...
                'betarange', props.betaRange, ...
                'orient', props.orientation );
        case 'ir'
    daffv17_write( 'filename', daffv17_output_file_path, ...                
                'metadata', metadata_v17, ...
                'datafunc', @dfConvertFromDAFFv15IR, ...
                'userdata', h, ...
                'content', props.contentType, ...
                'quantization', props.quantization, ...
                'channels', props.numChannels, ...
                'alphares', props.alphaResolution, ...
                'alpharange', props.alphaRange, ...
                'betares', props.betaResolution, ...
                'betarange', props.betaRange, ...
                'orient', props.orientation );
        case 'dft'
    daffv17_write( 'filename', daffv17_output_file_path, ...                
                'metadata', metadata_v17, ...
                'datafunc', @dfConvertFromDAFFv15DFT, ...
                'userdata', h, ...
                'content', props.contentType, ...
                'quantization', props.quantization, ...
                'channels', props.numChannels, ...
                'alphares', props.alphaResolution, ...
                'alpharange', props.alphaRange, ...
                'betares', props.betaResolution, ...
                'betarange', props.betaRange, ...
                'orient', props.orientation );
    end
    
    DAFFv15( 'close', h );
end